/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef egytarh
#define egytarh

#include <QWidget>

#include "con.h"

class QWidget;
class jelzpn;
class egykl;
class egytr : public QWidget
<%
	Q_OBJECT
	public:
		egytr(QWidget *felvnl, jelzpn *nybnvn);

		jelzpn *kidlgz;
		egykl *kelt;

	public slots:
		void kivalt(const zagv&);
%>;

#endif

